
From: Andrew Morton <akpm@osdl.org>

If we're inside preempt_disable() then there is no need for
raw_smp_processor_id().

Cc: David Howells <dhowells@redhat.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 kernel/printk.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff -puN kernel/printk.c~provide-better-printk-support-for-smp-machines-tidy kernel/printk.c
--- 25/kernel/printk.c~provide-better-printk-support-for-smp-machines-tidy	Fri Jul  8 16:29:39 2005
+++ 25-akpm/kernel/printk.c	Fri Jul  8 16:29:39 2005
@@ -526,14 +526,14 @@ asmlinkage int vprintk(const char *fmt, 
 	static int log_level_unknown = 1;
 
 	preempt_disable();
-	if (unlikely(oops_in_progress) && printk_cpu == raw_smp_processor_id())
+	if (unlikely(oops_in_progress) && printk_cpu == smp_processor_id())
 		/* If a crash is occurring during printk() on this CPU,
 		 * make sure we can't deadlock */
 		zap_locks();
 
 	/* This stops the holder of console_sem just where we want him */
 	spin_lock_irqsave(&logbuf_lock, flags);
-	printk_cpu = raw_smp_processor_id();
+	printk_cpu = smp_processor_id();
 
 	/* Emit the output into the temporary buffer */
 	printed_len = vscnprintf(printk_buf, sizeof(printk_buf), fmt, args);
@@ -595,7 +595,7 @@ asmlinkage int vprintk(const char *fmt, 
 			log_level_unknown = 1;
 	}
 
-	if (!cpu_online(raw_smp_processor_id())) {
+	if (!cpu_online(smp_processor_id())) {
 		/*
 		 * Some console drivers may assume that per-cpu resources have
 		 * been allocated.  So don't allow them to be called by this
_
